@@ -8,6 +8,7 @@ except ImportError:
 from django.db.models.fields import FieldDoesNotExist
 from django.db.models.related import RelatedObject
 from django.utils.translation import ugettext as _
+from signals import facebook_api_post_fetch
 from utils import graph
 from datetime import datetime
 import fields
@@ -56,8 +57,7 @@ class FacebookGraphManager(models.Manager):
             if len(parts) == 3:
                 slug = parts[2]
 
-        # TODO: change to self.get method
-        return self.fetch(slug)
+        return self.get(slug)
 
     def get_or_create_from_instance(self, instance):
 
@@ -73,6 +73,7 @@ class FacebookGraphManager(models.Manager):
             instance.save()
             log.debug('Fetch and create new object %s with remote pk %s' % (self.model, remote_pk_dict))
 
+        facebook_api_post_fetch.send(sender=instance.__class__, instance=instance, created=(not old_instance))
         return instance
 
     def get_or_create_from_resource(self, response, extra_fields=None):
@@ -234,4 +235,4 @@ class FacebookGraphIDModel(FacebookGraphModel):
     def get_url(self, slug=None):
         if slug is None:
             slug = self.graph_id
-        return 'http://facebook.com/%s' % slug
\ No newline at end of file
+        return 'http://facebook.com/%s' % slug
